==> zio-aws-kinesisanalyticsv2_2.13-5.17.130.5-sources.jar: zio/aws/kinesisanalyticsv2/model/Output.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.InAppStreamName
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Output(
    name: InAppStreamName,
    kinesisStreamsOutput: Option[
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput
    ] = None,
    kinesisFirehoseOutput: Option[
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput
    ] = None,
    lambdaOutput: Option[zio.aws.kinesisanalyticsv2.model.LambdaOutput] = None,
    destinationSchema: zio.aws.kinesisanalyticsv2.model.DestinationSchema
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.Output = {
    import Output.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
      .builder()
      .name(InAppStreamName.unwrap(name): java.lang.String)
      .optionallyWith(kinesisStreamsOutput.map(value => value.buildAwsValue()))(
        _.kinesisStreamsOutput
      )
      .optionallyWith(
        kinesisFirehoseOutput.map(value => value.buildAwsValue())
      )(_.kinesisFirehoseOutput)
      .optionallyWith(lambdaOutput.map(value => value.buildAwsValue()))(
        _.lambdaOutput
      )
      .destinationSchema(destinationSchema.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.kinesisanalyticsv2.model.Output.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.Output.wrap(buildAwsValue())
}
object Output {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.Output =
      zio.aws.kinesisanalyticsv2.model.Output(
        name,
        kinesisStreamsOutput.map(value => value.asEditable),
        kinesisFirehoseOutput.map(value => value.asEditable),
        lambdaOutput.map(value => value.asEditable),
        destinationSchema.asEditable
      )
    def name: InAppStreamName
    def kinesisStreamsOutput
        : Option[zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.ReadOnly]
    def kinesisFirehoseOutput: Option[
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.ReadOnly
    ]
    def lambdaOutput
        : Option[zio.aws.kinesisanalyticsv2.model.LambdaOutput.ReadOnly]
    def destinationSchema
        : zio.aws.kinesisanalyticsv2.model.DestinationSchema.ReadOnly
    def getName: ZIO[Any, Nothing, InAppStreamName] = ZIO.succeed(name)
    def getKinesisStreamsOutput: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.ReadOnly
    ] = AwsError.unwrapOptionField("kinesisStreamsOutput", kinesisStreamsOutput)
    def getKinesisFirehoseOutput: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.ReadOnly
    ] =
      AwsError.unwrapOptionField("kinesisFirehoseOutput", kinesisFirehoseOutput)
    def getLambdaOutput: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.LambdaOutput.ReadOnly
    ] = AwsError.unwrapOptionField("lambdaOutput", lambdaOutput)
    def getDestinationSchema: ZIO[
      Any,
      Nothing,
      zio.aws.kinesisanalyticsv2.model.DestinationSchema.ReadOnly
    ] = ZIO.succeed(destinationSchema)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
  ) extends zio.aws.kinesisanalyticsv2.model.Output.ReadOnly {
    override val name: InAppStreamName =
      zio.aws.kinesisanalyticsv2.model.primitives.InAppStreamName(impl.name())
    override val kinesisStreamsOutput: Option[
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.ReadOnly
    ] = scala
      .Option(impl.kinesisStreamsOutput())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.wrap(value)
      )
    override val kinesisFirehoseOutput: Option[
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.ReadOnly
    ] = scala
      .Option(impl.kinesisFirehoseOutput())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.wrap(value)
      )
    override val lambdaOutput
        : Option[zio.aws.kinesisanalyticsv2.model.LambdaOutput.ReadOnly] = scala
      .Option(impl.lambdaOutput())
      .map(value => zio.aws.kinesisanalyticsv2.model.LambdaOutput.wrap(value))
    override val destinationSchema
        : zio.aws.kinesisanalyticsv2.model.DestinationSchema.ReadOnly =
      zio.aws.kinesisanalyticsv2.model.DestinationSchema
        .wrap(impl.destinationSchema())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
  ): zio.aws.kinesisanalyticsv2.model.Output.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kinesisanalyticsv2_2.13-6.20.103.2-sources.jar: zio/aws/kinesisanalyticsv2/model/Output.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.InAppStreamName
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Output(
    name: InAppStreamName,
    kinesisStreamsOutput: Optional[
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput
    ] = Optional.Absent,
    kinesisFirehoseOutput: Optional[
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput
    ] = Optional.Absent,
    lambdaOutput: Optional[zio.aws.kinesisanalyticsv2.model.LambdaOutput] =
      Optional.Absent,
    destinationSchema: zio.aws.kinesisanalyticsv2.model.DestinationSchema
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.Output = {
    import Output.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
      .builder()
      .name(InAppStreamName.unwrap(name): java.lang.String)
      .optionallyWith(kinesisStreamsOutput.map(value => value.buildAwsValue()))(
        _.kinesisStreamsOutput
      )
      .optionallyWith(
        kinesisFirehoseOutput.map(value => value.buildAwsValue())
      )(_.kinesisFirehoseOutput)
      .optionallyWith(lambdaOutput.map(value => value.buildAwsValue()))(
        _.lambdaOutput
      )
      .destinationSchema(destinationSchema.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.kinesisanalyticsv2.model.Output.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.Output.wrap(buildAwsValue())
}
object Output {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.Output =
      zio.aws.kinesisanalyticsv2.model.Output(
        name,
        kinesisStreamsOutput.map(value => value.asEditable),
        kinesisFirehoseOutput.map(value => value.asEditable),
        lambdaOutput.map(value => value.asEditable),
        destinationSchema.asEditable
      )
    def name: InAppStreamName
    def kinesisStreamsOutput: Optional[
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.ReadOnly
    ]
    def kinesisFirehoseOutput: Optional[
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.ReadOnly
    ]
    def lambdaOutput
        : Optional[zio.aws.kinesisanalyticsv2.model.LambdaOutput.ReadOnly]
    def destinationSchema
        : zio.aws.kinesisanalyticsv2.model.DestinationSchema.ReadOnly
    def getName: ZIO[Any, Nothing, InAppStreamName] = ZIO.succeed(name)
    def getKinesisStreamsOutput: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.ReadOnly
    ] = AwsError.unwrapOptionField("kinesisStreamsOutput", kinesisStreamsOutput)
    def getKinesisFirehoseOutput: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.ReadOnly
    ] =
      AwsError.unwrapOptionField("kinesisFirehoseOutput", kinesisFirehoseOutput)
    def getLambdaOutput: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.LambdaOutput.ReadOnly
    ] = AwsError.unwrapOptionField("lambdaOutput", lambdaOutput)
    def getDestinationSchema: ZIO[
      Any,
      Nothing,
      zio.aws.kinesisanalyticsv2.model.DestinationSchema.ReadOnly
    ] = ZIO.succeed(destinationSchema)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
  ) extends zio.aws.kinesisanalyticsv2.model.Output.ReadOnly {
    override val name: InAppStreamName =
      zio.aws.kinesisanalyticsv2.model.primitives.InAppStreamName(impl.name())
    override val kinesisStreamsOutput: Optional[
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.kinesisStreamsOutput())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutput.wrap(value)
      )
    override val kinesisFirehoseOutput: Optional[
      zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.kinesisFirehoseOutput())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.KinesisFirehoseOutput.wrap(value)
      )
    override val lambdaOutput
        : Optional[zio.aws.kinesisanalyticsv2.model.LambdaOutput.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lambdaOutput())
        .map(value => zio.aws.kinesisanalyticsv2.model.LambdaOutput.wrap(value))
    override val destinationSchema
        : zio.aws.kinesisanalyticsv2.model.DestinationSchema.ReadOnly =
      zio.aws.kinesisanalyticsv2.model.DestinationSchema
        .wrap(impl.destinationSchema())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.Output
  ): zio.aws.kinesisanalyticsv2.model.Output.ReadOnly = new Wrapper(impl)
}
